==> example-btu-0.0.3.tar.gz: example-btu-0.0.3/src/example_btu/example.py <==
MORSE_CODE_DICT = {'A': '.-',
                   'B': '-...',
                   'C': '-.-.',
                   'D': '-..',
                   'E': '.',
                   'F': '..-.',
                   'G': '--.',
                   'H': '....',
                   'I': '..',
                   'J': '.---',
                   'K': '-.-',
                   'L': '.-..',
                   'M': '--',
                   'N': '-.',
                   'O': '---',
                   'P': '.--.',
                   'Q': '--.-',
                   'R': '.-.',
                   'S': '...',
                   'T': '-',
                   'U': '..-',
                   'V': '...-',
                   'W': '.--',
                   'X': '-..-',
                   'Y': '-.--',
                   'Z': '--..',
                   '1': '.----',
                   '2': '..---',
                   '3': '...--',
                   '4': '....-',
                   '5': '.....',
                   '6': '-....',
                   '7': '--...',
                   '8': '---..',
                   '9': '----.',
                   '0': '-----',
                   ', ': '--..--',
                   '.': '.-.-.-',
                   '?': '..--..',
                   '/': '-..-.',
                   '-': '-....-',
                   '(': '-.--.',
                   ')': '-.--.-'
}

ANIMALS_FACTS = [
    {"question": "What is the name of the fastest land animal?", "answer": "Cheetah"},
    {"question": "What’s the only mammal that’s able to fly?", "answer": "Bat"},
    {"question": "What’s a group of kittens called?", "answer": "Kindle"},
    {"question": "What are the horns of a rhinoceros made of?", "answer": "Hair"},
    {"question": "What name is given to a female deer?", "answer": "Doe"},
    {"question": "What animal is known by the nickname “sea cow?”", "answer": "Manatees"},
    {"question": "What animal is said to have 9 lives?", "answer": "Cat"},
    {"question": "What is the only mammals that can’t jump?", "answer": "Elephant"},
    {"question": "What animal eats mainly bamboo?", "answer": "Panda"},
    {"question": "Which animal can stand on its tail?", "answer": "Kangaroo"},
    {"question": "Which animal is the tallest in the world?", "answer": "Giraffe"},
    {"question": "What animal is covered in quills?", "answer": "Porcupine"}
]

HISTORY_FACTS = [
    {"question": "One of the ancient world wonders, the Hanging Gardens, was found in which city?", "answer": "Babylon"},
    {"question": "Greenland was a colony of which country until 1981?", "answer": "Denmark"},
    {"question": "How many days in a week were there in ancient Roman times?", "answer": "8"},
    {"question": "How many days was William Harrison President of the United States?", "answer": "32"},
    {"question": "What was the family name of the Russian rulers from the 17th century until the 1917 revolution?", "answer": "Romanov"},
    {"question": "How many U.S. presidents have been assassinated?", "answer": "4"},
    {"question": "When did Mao Zedong come to power?", "answer": "1949"},
    {"question": "In which country did the Easter Rising take place in 1916?", "answer": "Ireland"},
    {"question": "Which Greek historian is known as the Father of History?", "answer": "Herodotus"},
    {"question": "The Ptolemy dynasty ruled which ancient kingdom?", "answer": "Egypt"},
    {"question": "The ancient city of Rome was built on how many hills?", "answer": "7"},
    {"question": "The Peloponnesian War was fought between Athens and which other ancient Greek state?", "answer": "Sparta"},
    {"question": "What is the name of the first human civilization?", "answer": "Mesopotamia"}
]

==> example-btu-0.0.4.tar.gz: example-btu-0.0.4/src/example_btu/example.py <==
MORSE_CODE_DICT = {'A': '.-',
                   'B': '-...',
                   'C': '-.-.',
                   'D': '-..',
                   'E': '.',
                   'F': '..-.',
                   'G': '--.',
                   'H': '....',
                   'I': '..',
                   'J': '.---',
                   'K': '-.-',
                   'L': '.-..',
                   'M': '--',
                   'N': '-.',
                   'O': '---',
                   'P': '.--.',
                   'Q': '--.-',
                   'R': '.-.',
                   'S': '...',
                   'T': '-',
                   'U': '..-',
                   'V': '...-',
                   'W': '.--',
                   'X': '-..-',
                   'Y': '-.--',
                   'Z': '--..',
                   '1': '.----',
                   '2': '..---',
                   '3': '...--',
                   '4': '....-',
                   '5': '.....',
                   '6': '-....',
                   '7': '--...',
                   '8': '---..',
                   '9': '----.',
                   '0': '-----',
                   ', ': '--..--',
                   '.': '.-.-.-',
                   '?': '..--..',
                   '/': '-..-.',
                   '-': '-....-',
                   '(': '-.--.',
                   ')': '-.--.-'
}

ANIMALS_FACTS = [
    {"question": "What is the name of the fastest land animal?", "answer": "Cheetah"},
    {"question": "What’s the only mammal that’s able to fly?", "answer": "Bat"},
    {"question": "What’s a group of kittens called?", "answer": "Kindle"},
    {"question": "What are the horns of a rhinoceros made of?", "answer": "Hair"},
    {"question": "What name is given to a female deer?", "answer": "Doe"},
    {"question": "What animal is known by the nickname “sea cow?”", "answer": "Manatees"},
    {"question": "What animal is said to have 9 lives?", "answer": "Cat"},
    {"question": "What is the only mammals that can’t jump?", "answer": "Elephant"},
    {"question": "What animal eats mainly bamboo?", "answer": "Panda"},
    {"question": "Which animal can stand on its tail?", "answer": "Kangaroo"},
    {"question": "Which animal is the tallest in the world?", "answer": "Giraffe"},
    {"question": "What animal is covered in quills?", "answer": "Porcupine"}
]

HISTORY_FACTS = [
    {"question": "One of the ancient world wonders, the Hanging Gardens, was found in which city?", "answer": "Babylon"},
    {"question": "Greenland was a colony of which country until 1981?", "answer": "Denmark"},
    {"question": "How many days in a week were there in ancient Roman times?", "answer": "8"},
    {"question": "How many days was William Harrison President of the United States?", "answer": "32"},
    {"question": "What was the family name of the Russian rulers from the 17th century until the 1917 revolution?", "answer": "Romanov"},
    {"question": "How many U.S. presidents have been assassinated?", "answer": "4"},
    {"question": "When did Mao Zedong come to power?", "answer": "1949"},
    {"question": "In which country did the Easter Rising take place in 1916?", "answer": "Ireland"},
    {"question": "Which Greek historian is known as the Father of History?", "answer": "Herodotus"},
    {"question": "The Ptolemy dynasty ruled which ancient kingdom?", "answer": "Egypt"},
    {"question": "The ancient city of Rome was built on how many hills?", "answer": "7"},
    {"question": "The Peloponnesian War was fought between Athens and which other ancient Greek state?", "answer": "Sparta"},
    {"question": "What is the name of the first human civilization?", "answer": "Mesopotamia"}
]

LITERATURE_FACTS = [
    {"question": "Who is the author of The Origin Of Species?", "answer": "Darwin"},
    {"question": "People of which religion consider ‘The Bhagavad Gita’ as their sacred text?", "answer": "Hinduism"},
    {"question": "Mention the exact number of sonnets written by William Shakespeare?", "answer": "154"},
    {"question": "Mr. Freeze’ is the arch-enemy of a famous superhero of a comic book. What is the name of that superhero?", "answer": "Batman"},
    {"question": "In Which Book of the Holy Bible did the death of Moses take place?", "answer": "Deuteronomy"},
    {"question": "The ‘Almagest’ is a book written by a Greek Astronomer. What is the name of him?", "answer": "Ptolemy"},
    {"question": "Which novel of William Peter Blatty written in 1971? It has been adopted in which epic Horror Film?", "answer": "Exorcist"},
    {"question": "Find the missing word in the Best Selling Book by Barak Obama: ‘The Audacity Of _______.’", "answer": "Hope"},
    {"question": "In all the plays written by Shakespeare, only one contains the name of an animal. Name the animal.", "answer": "Shrew"},
    {"question": "Mention the year in which the first free library of Britain opened?", "answer": "1852"},
    {"question": "Name the Italian Astronomer who is the author of The Starry Messenger?", "answer": "Galileo"},
    {"question": "Name the Shakespearean character who had spoken the maximum number of lines?", "answer": "Hamlet"}
]
